
PRO NETCDF

;Reads and plots 94 GHz radar data from a NetCDF file

datafile = 'c:\data\netcdf\19990612_94.nc'
save_path = 'c:\idl_programs\output\'			;for resulting gif image
minval = -50.0									;value for bottom of scale
maxval = 10.0									;value for top of scale

cdfid = NCDF_OPEN(datafile)

NCDF_ATTGET, cdfid, /GLOBAL, 'day', day
NCDF_ATTGET, cdfid, /GLOBAL, 'month', month
NCDF_ATTGET, cdfid, /GLOBAL, 'year', year

;Reading time
time_varid = NCDF_VARID(cdfid, 'time')
IF (time_varid eq -1) THEN MESSAGE, 'Sorry, time variable not in the file'
NCDF_VARGET, cdfid, 'time', time
HELP, time

;Reading range
range_varid = NCDF_VARID(cdfid, 'range')
IF (range_varid eq -1) THEN MESSAGE, 'Sorry, range variable not in the file'
NCDF_VARGET, cdfid, 'range', range
HELP, range

;Reading zh
zh_varid = NCDF_VARID(cdfid, 'Zh')
IF (zh_varid eq -1) THEN MESSAGE, 'Sorry, Zh variable not in the file'
NCDF_VARGET, cdfid, 'Zh', zh
HELP, zh

NCDF_CLOSE, 0

;Plot a TV image

result = SIZE(range)
num_gates = result(1)
result = SIZE(time)
num_times = result(1)

zh = TRANSPOSE(zh)

;There is a value every 30 seconds or 0.00833333 hours
;The new zh array will have 2880 time slots
zh2 = FLTARR(2880, num_gates)
zh2(*,*) = -999.0

missing_slots = 0
n_delays = 0

FOR i = 0, num_times-1 DO BEGIN
  IF (i eq 0) THEN delay = time(i) - 0.0 ELSE delay = time(i) - time(i-1)
  IF (delay gt 0.0084) THEN BEGIN
    PRINT, 'delay is ', delay, '  No. of 30 sec periods is', delay/0.00833333
    n_delays = n_delays+1
    missing = FIX(delay/0.00833333) - 1
    PRINT, 'Missing ', missing, ' time slots'
    missing_slots = missing_slots + missing
  ENDIF
  zh2(i+missing_slots,*) = zh(i,*)
ENDFOR

;Last time is special case
delay = 24.0 - time(num_times-1)
IF (delay gt 0.0084) THEN BEGIN
  PRINT, 'delay is ', delay, '  No. of 30 sec periods is', delay/0.00833333
  n_delays = n_delays+1
  missing = FIX(delay/0.00833333) - 1
  PRINT, 'Missing ', missing, ' time slots'
  missing_slots = missing_slots + missing
ENDIF

;Sometimes all the time slots are not filled because there are not whole numbers of
;time slots in the gaps
PRINT, 'Total time slots is ', num_times + missing_slots
IF (num_times + missing_slots lt 2880-n_delays) THEN MESSAGE, 'Total time slots incorrect'

;Load a white plus rainbow plus black table with the saved r, g, b vectors
RESTORE, 'mycolors.sav'
TVLCT, r,g,b

!P.font = -1
WINDOW, 0, xsize=675, ysize=250

!P.position = [0.1, 0.15, 0.9, 0.9]
;Need to run PLOT, otherwise !X.window isn't set to the !P.position values
PLOT, [0,1],[0,1], /nodata, xstyle = 4, ystyle = 4

PX = !X.window * !D.X_size              ;Get size of plot window in device pixels
PY = !Y.window * !D.Y_size
SX = PX(1) - PX(0) + 1					;Desired size of image in pixels
SY = PY(1) - PY(0) + 1

;Create an SX by SY image stretched from the original
image = CONGRID(BYTSCL(zh2, MIN=minval, MAX=maxval, TOP=!D.table_size-2, /NAN), SX, SY)

;Display image with the same lower left corner coordinate as the plot window
TV, image, PX(0), PY(0)

IF (month eq 1) THEN month2 = 'Jan'
IF (month eq 2) THEN month2 = 'Feb'
IF (month eq 3) THEN month2 = 'Mar'
IF (month eq 4) THEN month2 = 'Apr'
IF (month eq 5) THEN month2 = 'May'
IF (month eq 6) THEN month2 = 'Jun'
IF (month eq 7) THEN month2 = 'Jul'
IF (month eq 8) THEN month2 = 'Aug'
IF (month eq 9) THEN month2 = 'Sep'
IF (month eq 10) THEN month2 = 'Oct'
IF (month eq 11) THEN month2 = 'Nov'
IF (month eq 12) THEN month2 = 'Dec'
date = STRING(day,month2,year, /PRINT, FORMAT = '(I2,1X,A3,1X,I4)')

PLOT, [0,MAX(time)],[0,MAX(range)], /NOERASE, /NODATA, xtitle = 'Time (UTC)', $
  ytitle = 'Height (km)', title = 'Chilbolton 94 GHz radar (Galileo) '+ date,$
  xstyle = 1, ystyle = 1, color = !D.n_colors-1, charsize = 1.0, yminor = 1, $
  Xtickformat = '(I2, ":00")'

COL_SCAL2, minval, maxval,!D.n_colors-2,'dBZ',0,1.0, !D.n_colors-1

save_file = save_path + STRING(year, month, day, FORMAT = '(I4,I2.2,I2.2)') + '_94_Zh.gif'
PRINT, 'gif file is ', save_file
WRITE_GIF,save_file,tvrd(), r, g, b

PRINT, 'Finished normally'

END